==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/resource/api/type/gwt/endpoint/ResourceTypeUidsGwtEndpoint.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.resource.api.type.gwt.endpoint;

import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.commons.gwt.EndpointRequestCallback;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.http.client.RequestBuilder;
import com.google.gwt.http.client.RequestException;
import com.google.gwt.json.client.JSONValue;
import java.util.List;
import java.util.Map;
import java.util.Set;
import net.bluemind.core.api.Stream;
import java.lang.Long;

public class ResourceTypeUidsGwtEndpoint implements net.bluemind.resource.api.type.IResourceTypeUidsAsync {

	private String baseUri;

	private String sessionId;

	private String root = "/api";

	public ResourceTypeUidsGwtEndpoint(String sessionId, String... pathVars) {
		String uri_ = "/mailbox/uids";
		this.sessionId = sessionId;
	

		baseUri = uri_;
	}

	public ResourceTypeUidsGwtEndpoint withRoot(String root) {
		this.root = root;
		return this;
	}

	@Override
	public void identifier(String domain, final AsyncHandler<String> handler) {
		String postUri = "/{domain}/_resource_type";

		postUri = postUri.replace("{domain}", ""+domain);
		String uri_ = baseUri + postUri;

		String queryParams = "?";
		uri_ += queryParams;
		String bodyContent = null;
		RequestBuilder builder = new RequestBuilder(RequestBuilder.GET, root + uri_);
		builder.setHeader("X-BM-ApiKey", sessionId);

		builder.setHeader("Accept", "application/json");
		builder.setRequestData(bodyContent);
		builder.setCallback( new EndpointRequestCallback<String>(handler) {
			@Override
			protected String handleResponse(
							JSONValue jsonValue) {
				return GwtSerDerUtils.STRING.deserialize( jsonValue);
			}
		});


		try {
			builder.send();
		} catch (RequestException e) {
			handler.failure(e);
		}
	}

	public net.bluemind.resource.api.type.IResourceTypeUidsPromise promiseApi() {
		return new ResourceTypeUidsEndpointPromise(this);
	}
}

==> net.bluemind.p2.platform-5.5.3112.zip: net/bluemind/resource/api/type/gwt/endpoint/ResourceTypeUidsGwtEndpoint.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.resource.api.type.gwt.endpoint;

import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.commons.gwt.EndpointRequestCallback;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONValue;
import com.google.gwt.http.client.RequestBuilder;
import com.google.gwt.http.client.RequestException;
import com.google.gwt.http.client.URL;
import java.util.List;
import java.util.Map;
import java.util.Set;
import net.bluemind.core.api.Stream;
import java.lang.Long;

public class ResourceTypeUidsGwtEndpoint implements net.bluemind.resource.api.type.IResourceTypeUidsAsync {

	private String baseUri;

	private String sessionId;

	private String root = "/api";

	public ResourceTypeUidsGwtEndpoint(String sessionId, String... pathVars) {
		String uri_ = "/mailbox/uids";
		this.sessionId = sessionId;
	

		baseUri = uri_;
	}

	public ResourceTypeUidsGwtEndpoint withRoot(String root) {
		this.root = root;
		return this;
	}

	@Override
	public void identifier(String domain, final AsyncHandler<String> handler) {
		String postUri = "/{domain}/_resource_type";

		postUri = postUri.replace("{domain}", URL.encodePathSegment(""+domain));
		String uri_ = baseUri + postUri;

		String queryParams = "?";
		uri_ += queryParams;
		String bodyContent = null;
		RequestBuilder builder = new RequestBuilder(RequestBuilder.GET, root + uri_);
		builder.setHeader("X-BM-ApiKey", sessionId);

		builder.setHeader("Accept", "application/json");
		builder.setRequestData(bodyContent);
		builder.setCallback( new EndpointRequestCallback<String>(handler) {
			@Override
			protected String handleResponse(
							JSONValue jsonValue) {
				return GwtSerDerUtils.STRING.deserialize( jsonValue);
			}
		});


		try {
			builder.send();
		} catch (RequestException e) {
			handler.failure(e);
		}
	}

	public net.bluemind.resource.api.type.IResourceTypeUidsPromise promiseApi() {
		return new ResourceTypeUidsEndpointPromise(this);
	}
}
